@@ -1,9 +1,11 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-'''Utilities
-'''
+"""
+Utilities
+"""
 
 
 class Ex(Exception):
-    '''Exception wrapping all exceptions of this package'''
+    """Exception wrapping all exceptions of this package"""
+
     pass
